@@ -210,6 +210,23 @@ def set_bv_target_column(df):
     #   df = df[df.BV < 40]
     return df
 
+def set_bv_fake_column(df):
+    if('BV' in df.columns):
+        logger.info('Setting BV fake target ')
+        n = len(df)
+        df['BV']= np.ones(n)
+        date_col = df['campaign_bulk_date']
+        df.drop( labels=['campaign_bulk_date'], axis=1, inplace=True )
+        df.insert(loc=0, value=date_col, column= 'campaign_bulk_date')
+        bv_col = df['BV']
+        df.drop( labels=['BV'], axis=1, inplace=True )
+        df.insert( loc=1, value=bv_col, column='BV' )
+
+    else:
+        logger.error('No BV column found')
+        raise Exception('No BV column found!!!!!')
+    return df
+
 
 def set_bv_discrete_target_column(df,bins):
     if('BV' in df.columns):
@@ -229,6 +246,8 @@ def set_target_column(df,model_type,bins):
         df = set_bv_target_column( df=df )
     elif model_type == 'multiclass':
         df = set_bv_discrete_target_column( df=df,bins=bins )
+    elif model_type == 'bvfake':
+        df = set_bv_discrete_target_column( df=df,bins=bins )
     else:
         raise Exception( 'Incorrect model_type !!!!!' )
     return df
